@@ -1,6 +1,6 @@
-###
-# spike_bt - Implement a back-tick precise spike time recurrent layer, with fast and slow synapses
-###
+"""
+A back-tick precise spike time recurrent layer, with fast and slow synapses
+"""
 
 ### --- Imports
 
@@ -11,13 +11,6 @@ import numpy as np
 from typing import Union, Callable, Optional, Tuple, Any
 import copy
 
-from importlib import util
-
-if util.find_spec("numba") is None:
-    raise ModuleNotFoundError(
-        "'numba' backend not found. Modules that rely on numba will not be available."
-    )
-
 from numba import njit
 
 # - Try to import holoviews
@@ -512,12 +505,12 @@ class RecFSSpikeEulerBT(Layer):
 
     @property
     def output_type(self):
-        """ (`TSEvent`) Output `TimeSeries` class (`TSEvent`) """
+        """(`TSEvent`) Output `TimeSeries` class (`TSEvent`)"""
         return TSEvent
 
     @property
     def tau_syn_r_f(self):
-        """ (flot) Fast synaptic time constant (s) """
+        """(flot) Fast synaptic time constant (s)"""
         return self.__tau_syn_r_f
 
     @tau_syn_r_f.setter
@@ -526,7 +519,7 @@ class RecFSSpikeEulerBT(Layer):
 
     @property
     def tau_syn_r_s(self):
-        """ (float) Slow synaptic time constant (s) """
+        """(float) Slow synaptic time constant (s)"""
         return self.__tau_syn_r_s
 
     @tau_syn_r_s.setter
@@ -535,7 +528,7 @@ class RecFSSpikeEulerBT(Layer):
 
     @property
     def v_thresh(self):
-        """ (float) Threshold potential """
+        """(float) Threshold potential"""
         return self.__thresh
 
     @v_thresh.setter
@@ -544,7 +537,7 @@ class RecFSSpikeEulerBT(Layer):
 
     @property
     def v_rest(self):
-        """ (float) Resting potential """
+        """(float) Resting potential"""
         return self.__rest
 
     @v_rest.setter
@@ -553,7 +546,7 @@ class RecFSSpikeEulerBT(Layer):
 
     @property
     def v_reset(self):
-        """ (float) Reset potential"""
+        """(float) Reset potential"""
         return self.__reset
 
     @v_reset.setter
