@@ -2,9 +2,16 @@
 Contains the module base classes for Rockpool
 """
 # - Rockpool imports
+import collections
+
 from rockpool.parameters import ParameterBase
 from rockpool.timeseries import TimeSeries
 
+try:
+    from rockpool.graph.graph_base import GraphModuleBase
+except:
+    GraphModuleBase = "GraphModuleBase"
+
 # - Other imports
 from abc import ABC, abstractmethod
 from warnings import warn
@@ -12,6 +19,8 @@ from collections import ChainMap
 from typing import Tuple, Any, Iterable, Dict, Optional, List, Union
 import numpy as np
 
+__all__ = ["Module"]
+
 
 class ModuleBase(ABC):
     """
@@ -20,7 +29,7 @@ class ModuleBase(ABC):
 
     def __init__(
         self,
-        shape: Optional[Tuple] = None,
+        shape: Optional[Union[Tuple, int]] = None,
         spiking_input: bool = False,
         spiking_output: bool = False,
         *args,
@@ -30,12 +39,19 @@ class ModuleBase(ABC):
         Initialise this module
 
         Args:
-            shape (Optional[Tuple]): The shape of the defined module
+            shape (Optional[Union[Tuple, int]]): The shape of the defined module
             spiking_input (bool): Whether this module receives spiking input. Default: False
             spiking_output (bool): Whether this module produces spiking output. Default: False
             *args: Additional positional arguments
             **kwargs: Additional keyword arguments
         """
+        # - Set flag to specify that we are in the `__init__()` method
+        self._in_Module_init = True
+        """ (bool) If exists and ``True``, indicates that the module is in the ``__init__`` chain."""
+
+        self._force_set_attributes = False
+        """ (bool) If ``True``, do not sanity-check attributes when setting. """
+
         # - Initialise co-classes etc.
         super().__init__(*args, **kwargs)
 
@@ -74,10 +90,12 @@ class ModuleBase(ABC):
         repr = f"{indent}{self.full_name} with shape {self._shape}"
 
         # - Add submodules
-        if self.modules():
+        if self._submodulenames:
             repr += " {"
-            for mod in self.modules().values():
-                repr += "\n" + ModuleBase.__repr__(mod, indent=indent + "    ")
+            for mod_name in self._submodulenames:
+                repr += "\n" + ModuleBase.__repr__(
+                    getattr(self, mod_name), indent=indent + "    "
+                )
 
             repr += f"\n{indent}" + "}"
 
@@ -117,7 +135,11 @@ class ModuleBase(ABC):
 
         # - Check if this is a new rockpool Parameter
         if isinstance(val, ParameterBase):
-            if hasattr(self, name):
+            if (
+                hasattr(self, name)
+                and hasattr(self, "_in_Module_init")
+                and not self._in_Module_init
+            ):
                 raise ValueError(
                     f'Cannot assign a new Parameter or State to an existing attribute "{name}".'
                 )
@@ -132,13 +154,19 @@ class ModuleBase(ABC):
 
         # - Check if this is an already registered attribute
         if name in __registered_attributes:
-            # - Check that shapes are identical
             if hasattr(self, name):
                 (_, _, _, _, shape) = __registered_attributes[name]
-                if np.shape(val) != shape and val is not None:
-                    raise ValueError(
-                        f"The new value assigned to {name} must be of shape {shape}."
-                    )
+
+                if val is not None:
+                    # - Should we force-set the attribute?
+                    if self._force_set_attributes:
+                        __registered_attributes[name][4] = np.shape(val)
+
+                    elif np.shape(val) != shape:
+                        # - Check that shapes are identical
+                        raise ValueError(
+                            f"The new value assigned to {name} must be of shape {shape} (got {np.shape(val)})."
+                        )
 
             # - Assign the value to the __registered_attributes dictionary
             __registered_attributes[name][0] = val
@@ -210,7 +238,8 @@ class ModuleBase(ABC):
 
         # - Assign to appropriate attribute dictionary
         __modules[name] = [mod, type(mod).__name__]
-        self._submodulenames.append(name)
+        if name not in self._submodulenames:
+            self._submodulenames.append(name)
 
     def set_attributes(self, new_attributes: dict) -> "ModuleBase":
         """
@@ -420,7 +449,7 @@ class ModuleBase(ABC):
         # - Get attribute registry
         __registered_attributes, __modules = self._get_attribute_registry()
 
-        return {k: m[0] for (k, m) in __modules.items()}
+        return collections.OrderedDict([(k, m[0]) for (k, m) in __modules.items()])
 
     def _reset_attribute(self, name: str) -> "ModuleBase":
         """
@@ -491,7 +520,7 @@ class ModuleBase(ABC):
         Reset all parameters in this module
 
         Returns:
-            Module: The updated module is returned for compatibility with the funcitonal API
+            Module: The updated module is returned for compatibility with the functional API
         """
         # - Get attribute registry
         __registered_attributes, __modules = self._get_attribute_registry()
@@ -528,22 +557,22 @@ class ModuleBase(ABC):
 
     @property
     def spiking_input(self) -> bool:
-        """ bool: If ``True``, this module receives spiking input. If ``False``, this module expects continuous input. """
+        """bool: If ``True``, this module receives spiking input. If ``False``, this module expects continuous input."""
         return self._spiking_input
 
     @property
     def spiking_output(self):
-        """ bool: If ``True``, this module sends spiking output. If ``False``, this module sends continuous output. """
+        """bool: If ``True``, this module sends spiking output. If ``False``, this module sends continuous output."""
         return self._spiking_output
 
     @property
     def shape(self) -> tuple:
-        """ tuple: The shape of this module """
+        """tuple: The shape of this module"""
         return self._shape
 
     @property
     def size(self) -> int:
-        """ int: (DEPRECATED) The output size of this module """
+        """int: (DEPRECATED) The output size of this module"""
         warn(
             "The `size` property is deprecated. Please use `size_out` instead.",
             DeprecationWarning,
@@ -552,12 +581,12 @@ class ModuleBase(ABC):
 
     @property
     def size_out(self) -> int:
-        """ int: The output size of this module """
+        """int: The output size of this module"""
         return self._shape[-1]
 
     @property
     def size_in(self) -> int:
-        """ int: The input size of this module """
+        """int: The input size of this module"""
         return self._shape[0]
 
     @abstractmethod
@@ -623,44 +652,55 @@ class ModuleBase(ABC):
         """
         return recorded_dict
 
+    def as_graph(self) -> GraphModuleBase:
+        """
+        Convert this module to a computational graph
 
-class Module(ModuleBase, ABC):
+        Returns:
+            GraphModuleBase: The computational graph corresponding to this module
+
+        Raises:
+            NotImplementedError: If :py:meth:`.as_graph` is not implemented for this subclass
+        """
+        raise NotImplementedError(
+            f"The Module class '{type(self).__name__}' used by module [{self}] does not implement the graph serialisation API"
+        )
+
+
+class PostInitMetaMixin(type(ModuleBase)):
     """
-    The native Python / numpy ``Module`` base class for Rockpool
+    A mixin base class that adds a ``__post_init__()`` method to a class. ``__post_init__()`` is called after the ``__init__()`` method, on instantiation of an object.
     """
 
-    pass
-    # def _register_module(self, name: str, mod: ModuleBase):
-    #     """
-    #     Register a submodule in the module registry
-    #
-    #     Args:
-    #         name (str): The name to assign to the submodule
-    #         mod (Module): The submodule to register. Must inherit from ``Module``
-    #     """
-    #     # - Register the module
-    #     super()._register_module(name, mod)
-    #
-    #     # - Do we even have a `dt` attribute?
-    #     if hasattr(self, "dt"):
-    #         # - Check that the submodule `dt` is the same as mine
-    #         if hasattr(mod, "dt"):
-    #             if mod.dt != getattr(self, "dt"):
-    #                 raise ValueError(
-    #                     f"The submodule {mod.name} must have the same `dt` as the parent module {self.name}"
-    #                 )
-    #         else:
-    #             # - Add `dt` as an attribute to the module (not a registered attribute)
-    #             mod.dt = getattr(self, "dt")
-    #
-    #     else:
-    #         # - We should inherit the first `dt` of a submodule
-    #         if hasattr(mod, "dt"):
-    #             setattr(self, "dt", mod.dt)
+    def __call__(cls, *args, **kwargs):
+        # - Instantiate the object
+        obj = super().__call__(*args, **kwargs)
+
+        # - Check for a `__post_init__` method
+        if hasattr(cls, "__post_init__"):
+            cls.__post_init__(obj)
+
+        # - Clear the init flag
+        obj._in_Module_init = False
+        return obj
+
+
+class Module(ModuleBase, ABC, metaclass=PostInitMetaMixin):
+    """
+    The native Python / numpy :py:class:`.Module` base class for Rockpool
+
+    This class acts as the base class for all "native" modules in Rockpool. To get started with using and writing your own Rockpool modules, see :ref:`/basics/getting_started.ipynb` and :ref:`/in-depth/api-low-level.ipynb`.
+
+    If you plan to write modules using Jax or Torch backends, you should use either :py:class:`.JaxModule` or :py:class:`.TorchModule` as base classes, respectively.
+
+    To get started with the Jax backend, see :ref:`/in-depth/api-functional.ipynb` and :ref:`/in-depth/jax-training.ipynb`.
+
+    To get started with the Torch backend, see :ref:`/in-depth/torch-api.ipynb` and :ref:`/in-depth/torch-training.ipynb`.
+    """
 
     def timed(self, output_num: int = 0, dt: float = None, add_events: bool = False):
         """
-        Convert this module to a :py:class:`TimedModule`
+        Convert this module to a :py:class:`.TimedModule`
 
         Args:
             output_num (int): Specify which output of the module to take, if the module returns multiple output series. Default: ``0``, take the first (or only) output.
@@ -675,15 +715,73 @@ class Module(ModuleBase, ABC):
             self, output_num=output_num, dt=dt, add_events=add_events
         )
 
+    def _auto_batch(
+        self,
+        data: np.ndarray,
+        states: Tuple = (),
+        target_shapes: Tuple = None,
+    ) -> (np.ndarray, Tuple[np.ndarray]):
+        """
+        Automatically replicate states over batches and verify input dimensions
 
-class PostInitMetaMixin(type(ModuleBase)):
-    """
-    A mixin base class that adds a ``__post_init__()`` method to a class. ``__post_init__()`` is called after the ``__init__()`` method, on instantiation of an object.
-    """
+        Examples:
+            >>> data, (state0, state1, state2) = self._auto_batch(data, (self.state0, self.state1, self.state2))
 
-    def __call__(cls, *args, **kwargs):
-        obj = super().__call__(*args, **kwargs)
-        if hasattr(cls, "__post_init__"):
-            cls.__post_init__(obj)
+            This will verify that ``data`` has the correct final dimension (i.e. ``self.size_in``).
 
-        return obj
+            If ``data`` has only two dimensions ``(T, Nin)``, then it will be augmented to ``(1, T, Nin)``. The individual states will be replicated out from shape ``(a, b, c, ...)`` to ``(n_batches, a, b, c, ...)`` and returned.
+
+            If ``data`` has only a single dimension ``(T,)``, it will be expanded to ``(1, T, self.size_in)``.
+
+            ``state0``, ``state1``, ``state2`` will be replicated out along the batch dimension.
+
+            >>> data, (state0,) = self._auto_batch(data, (self.state0,), ((10, -1, self.size_in),))
+
+            Attempt to replicate ``state0`` to a specified size ``(10, -1, self.size_in)``.
+
+        Args:
+            data (np.ndarray): Input data tensor. Either ``(batches, T, Nin)`` or ``(T, Nin)``
+            states (Tuple): Tuple of state variables. Each will be replicated out over batches by prepending a batch dimension
+            target_shapes (Tuple): A tuple of target size tuples, each corresponding to each state argument. The individual states will be replicated out to match the corresponding target sizes. If not provided (the default), then states will be only replicated along batches.
+
+        Returns:
+            (np.ndarray, Tuple[np.ndarray]) data, states
+        """
+        # - Ensure data is a float tensor
+        data = np.array(data, "float")
+
+        # - Verify input data shape
+        if len(data.shape) == 1:
+            data = np.expand_dims(data, 0)
+            data = np.expand_dims(data, 2)
+        elif len(data.shape) == 2:
+            data = np.expand_dims(data, 0)
+
+        if data.shape[-1] == 1:
+            data = np.broadcast_to(data, (data.shape[0], data.shape[1], self.size_in))
+
+        # - Get shape of input
+        (n_batches, time_steps, n_connections) = data.shape
+
+        # - Check input dimensions
+        if n_connections != self.size_in:
+            raise ValueError(
+                "Input has wrong neuron dimension. It is {}, must be {}".format(
+                    n_connections, self.size_in
+                )
+            )
+
+        # - Get target shapes
+        if target_shapes is None:
+            target_shapes = tuple(s.shape for s in states)
+        else:
+            target_shapes = tuple(
+                s.shape if shape is None else shape
+                for s, shape in zip(states, target_shapes)
+            )
+
+        # - Replicate shapes and return
+        states = tuple(
+            np.ones((n_batches, *shape)) * s for s, shape in zip(states, target_shapes)
+        )
+        return data, states
